summaryrefslogtreecommitdiffstats
path: root/kdat/VerifyDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/VerifyDlg.h')
-rw-r--r--kdat/VerifyDlg.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kdat/VerifyDlg.h b/kdat/VerifyDlg.h
index 0535cd4..bc11524 100644
--- a/kdat/VerifyDlg.h
+++ b/kdat/VerifyDlg.h
@@ -33,10 +33,11 @@ class LoggerWidget;
class TapeDrive;
/**
- * @short Status dialog for verifying/restoring parts of an archive.
+ * @short tqStatus dialog for verifying/restoring parts of an archive.
*/
class VerifyDlg : public TQDialog {
Q_OBJECT
+ TQ_OBJECT
bool _restore;
KProcess* _proc;
TQString _workingDir;
@@ -79,11 +80,11 @@ public:
* @param fileno The tape file number of the archive to verify/restore.
* @param ranges A list of tar block ranges to read.
* @param restore TRUE means restore, FALSE means verify.
* @param parent The parent widget for the dialog.
* @param name The name of this widget.
*/
VerifyDlg( const TQString & workingDir, int fileno, const RangeList& ranges,
- bool restore = FALSE, TQWidget* parent = 0, const char* name = 0 );
+ bool restore = FALSE, TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the verify/restore dialog.
@@ -79,11 +80,11 @@ public:
* @param ranges A list of tar block ranges to read.
* @param restore TRUE means restore, FALSE means verify.
- * @param parent The parent widget for the dialog.
+ * @param tqparent The tqparent widget for the dialog.
* @param name The name of this widget.
*/